@@ -66,20 +66,13 @@ namespace Oxygen
         void registerChild( GtkWidget* widget, GtkWidget* child )
         { data().value( widget ).registerChild( child ); }
 
-        //! initialize cell layout
-        void initializeCellLayout( GtkWidget* widget )
-        { data().value( widget ).initializeCellLayout(); }
-
         //@}
 
+        //!@name accessors
+        //@{
+
         //! returns pressed combobox if any
-        GtkWidget* pressedComboBox( void )
-        {
-            const DataMap<ComboBoxData>::Map& dataMap( data().map() );
-            for( DataMap<ComboBoxData>::Map::const_iterator iter = dataMap.begin(); iter != dataMap.end(); iter++ )
-            { if( iter->second.pressed() ) return iter->first; }
-            return 0L;
-        }
+        inline GtkWidget* pressedComboBox( void ) const;
 
         //! true if either button or is pressed
         bool pressed( GtkWidget* widget )
@@ -93,8 +86,19 @@ namespace Oxygen
         bool hovered( GtkWidget* widget )
         { return data().value( widget ).hovered(); }
 
+        //@}
+
     };
 
+    //_________________________________________________
+    GtkWidget* ComboBoxEngine::pressedComboBox( void ) const
+    {
+        const DataMap<ComboBoxData>::Map& dataMap( data().map() );
+        for( DataMap<ComboBoxData>::Map::const_iterator iter = dataMap.begin(); iter != dataMap.end(); iter++ )
+        { if( iter->second.pressed() ) return iter->first; }
+        return 0L;
+    }
+
 }
 
 #endif
