@@ -36,7 +36,7 @@ namespace Oxygen
     {
 
         #if OXYGEN_DEBUG
-        std::cout << "Oxygen::TabWidgetData::connect - " << widget << std::endl;
+        std::cerr << "Oxygen::TabWidgetData::connect - " << widget << std::endl;
         #endif
 
         _target = widget;
@@ -53,7 +53,7 @@ namespace Oxygen
     {
 
         #if OXYGEN_DEBUG
-        std::cout << "Oxygen::TabWidgetData::disconnect - " << widget << std::endl;
+        std::cerr << "Oxygen::TabWidgetData::disconnect - " << widget << std::endl;
         #endif
 
         _target = 0L;
@@ -108,6 +108,23 @@ namespace Oxygen
         _tabRects[index]=r;
     }
 
+    //________________________________________________________________________________
+    void TabWidgetData::setDirty( bool value )
+    {
+        if( _dirty == value ) return;
+        _dirty = value;
+        if( _dirty && _target )
+        {
+
+            // we should only update the tabbar rect here
+            GdkRectangle updateRect;
+            Gtk::gtk_notebook_get_tabbar_rect( GTK_NOTEBOOK( _target ), &updateRect );
+            Gtk::gtk_widget_queue_draw( _target, &updateRect );
+
+        }
+
+    }
+
     //________________________________________________________________________________
     void TabWidgetData::setHoveredTab( GtkWidget* widget, int index )
     {
@@ -146,7 +163,7 @@ namespace Oxygen
     void TabWidgetData::pageAddedEvent( GtkNotebook* parent, GtkWidget* child, guint, gpointer data)
     {
         #if OXYGEN_DEBUG
-        std::cout << "Oxygen::TabWidgetData::pageAddedEvent - " << child << std::endl;
+        std::cerr << "Oxygen::TabWidgetData::pageAddedEvent - " << child << std::endl;
         #endif
         static_cast<TabWidgetData*>(data)->updateRegisteredChildren( GTK_WIDGET( parent ) );
     }
@@ -181,7 +198,7 @@ namespace Oxygen
         {
 
             #if OXYGEN_DEBUG
-            std::cout << "Oxygen::TabWidgetData::registerChild - " << widget << std::endl;
+            std::cerr << "Oxygen::TabWidgetData::registerChild - " << widget << std::endl;
             #endif
 
             // allocate new ChildData
@@ -223,7 +240,7 @@ namespace Oxygen
         if( iter == _childrenData.end() ) return;
 
         #if OXYGEN_DEBUG
-        std::cout << "Oxygen::TabWidgetData::unregisterChild - " << widget << std::endl;
+        std::cerr << "Oxygen::TabWidgetData::unregisterChild - " << widget << std::endl;
         #endif
 
         iter->second.disconnect();
