@@ -50,12 +50,13 @@ namespace Oxygen
         virtual ~QtSettings( void )
         {}
 
+        //! returns user config dir
+        std::string userConfigDir( void ) const
+        { return _userConfigDir; }
+
         //! initialize
         void initialize( void );
 
-        //! initialize colors
-        void initializeColors( void );
-
         //! palette
         const Palette& palette( void ) const
         { return _palette; }
@@ -214,6 +215,10 @@ namespace Oxygen
 
         //@}
 
+        //! true if argb is enabled
+        bool argbEnabled( void ) const
+        { return _argbEnabled; }
+
         protected:
 
         // get home directory
@@ -228,9 +233,15 @@ namespace Oxygen
         //! add icon theme to path list, accounting for theme inheritance (recursively)
         void addIconTheme( PathList&, const std::string& );
 
+        //! init user config dir
+        void initUserConfigDir( void );
+
         //! init application name
         void initApplicationName( void );
 
+        //! init argb support
+        void initArgb( void );
+
         //! load kde icons
         void loadKdeIcons( void );
 
@@ -268,6 +279,9 @@ namespace Oxygen
         //! kde oxygen options
         OptionMap _oxygen;
 
+        //! user config directory
+        std::string _userConfigDir;
+
         //!@name icons
         //@{
 
@@ -371,6 +385,9 @@ namespace Oxygen
 
         //@}
 
+        //! true if argb is enabled
+        bool _argbEnabled;
+
         //! initialization flags
         bool _initialized;
         bool _kdeColorsInitialized;
