@@ -59,15 +59,15 @@ namespace Oxygen
             shadow=ColorUtils::Rgba(0,0,0);
         }
 
-        GdkPixbuf *windecoButtonGlow( helper().windecoButtonGlow( shadow, int(scale) ) );
-        gdk_cairo_set_source_pixbuf( context, windecoButtonGlow, 0, 0 );
+        const Cairo::Surface& windecoButtonGlow( helper().windecoButtonGlow( shadow, int(scale) ) );
+        cairo_set_source_surface( context, windecoButtonGlow, 0, 0 );
         cairo_rectangle( context, 0, 0, w, h );
         cairo_fill( context );
 
         // draw button slab
         const bool pressed( _state == Pressed || _type==ButtonUnstick );
-        GdkPixbuf* windecoButton( helper().windecoButton( base, pressed, int(scale) ) );
-        gdk_cairo_set_source_pixbuf( context, windecoButton, 0, 0 );
+        const Cairo::Surface& windecoButton( helper().windecoButton( base, pressed, int(scale) ) );
+        cairo_set_source_surface( context, windecoButton, 0, 0 );
         cairo_rectangle( context, 0, 0, w, h );
         cairo_fill( context );
 
